MODULE trcctl_idtra
   !!======================================================================
   !!                         ***  trcctl.idtra.F90  ***
   !! TOP :                Control of IDEAL-TRA chemical model
   !!======================================================================
   !!----------------------------------------------------------------------
   !! History :   1.0  !  2005-10 (C. Ethe) assign a parameter to name individual tracers
   !!----------------------------------------------------------------------

#if defined key_idtra

   USE oce_trc
   USE trc


   IMPLICIT NONE
   PRIVATE

   PUBLIC trc_ctl_idtra      ! called by ???

   !!----------------------------------------------------------------------
   !! NEMO/TOP 1.0 , LOCEAN-IPSL (2005)
   !! $Id$
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------

CONTAINS

   SUBROUTINE trc_ctl_idtra
      !!----------------------------------------------------------------------
      !!                     ***  ROUTINE trc_ctl_idtra  ***
      !!
      !! ** Purpose :   control the cpp options, namelist and files
      !!----------------------------------------------------------------------
      INTEGER :: jl, jn

      IF(lwp) THEN
          WRITE(numout,*) ' IDEAL-TRA Model '
          WRITE(numout,*) ' '
      ENDIF

      ! Check number of tracers
      ! -----------------------
      IF( jp_idtra > 5) THEN
          IF(lwp) THEN
              WRITE (numout,*) ' ===>>>> : w a r n i n g '
              WRITE (numout,*) ' =======   ============= '
              WRITE (numout,*)                             &
              &   ' STOP, change jp_idtra to 1 in par_IDEAL-TRA module '
          END IF
          STOP 'TRC_CTL'
      END IF

      ! Check tracer names
      ! ------------------
      IF ( ctrcnm(jpidtra) /= 'Ideal-Tracer' ) THEN
            ctrcnm(jpidtra) = 'Ideal-Tracer'
            ctrcln(jpidtra) = 'Ideal-Tracer concentration'
      ENDIF

      IF(lwp) THEN
         WRITE (numout,*) ' ===>>>> : w a r n i n g '
         WRITE (numout,*) ' =======   ============= '
         WRITE (numout,*) ' we force tracer names'
         DO jl = 1, jp_idtra
            jn = jp_idtra0 + jl - 1
            WRITE(numout,*) ' tracer nb: ',jn,' name = ',ctrcnm(jn), ctrcln(jn)
         END DO
         WRITE(numout,*) ' '
      ENDIF


      ! Check tracer units
      ! ------------------
      DO jl = 1, jp_idtra
         jn = jp_idtra0 + jl - 1
        IF( ctrcun(jn) /= 'unit' ) THEN
            ctrcun(jn) = 'unit'
            IF(lwp) THEN
               WRITE (numout,*) ' ===>>>> : w a r n i n g '
               WRITE (numout,*) ' =======   ============= '
               WRITE (numout,*) ' we force tracer unit'
               WRITE(numout,*) ' tracer  ',ctrcnm(jn), 'UNIT= ',ctrcun(jn)
               WRITE(numout,*) ' '
            ENDIF
         ENDIF
      END DO
      !
   END SUBROUTINE trc_ctl_idtra

#else
   !!----------------------------------------------------------------------
   !!  Empty module :                                                No IDEAL-TRA
   !!----------------------------------------------------------------------
CONTAINS
   SUBROUTINE trc_ctl_idtra                      ! Dummy routine
   END SUBROUTINE trc_ctl_idtra
#endif

   !!======================================================================
END MODULE trcctl_idtra




